@@ -30,6 +30,7 @@ aliases = {
     "claws-mail": ["org.claws_mail.Claws-Mail"],
     "converseen": ["net.fasterland.converseen"],
     "crow-translate": ["org.kde.CrowTranslate.svg"],
+    "cuttlefish": ["org.kde.iconexplorer"],
     "darktable": ["org.darktable.Darktable"],
     "diffuse": ["io.github.mightycreak.Diffuse"],
     "digikam": ["org.kde.digikam"],
@@ -47,7 +48,6 @@ aliases = {
     "haguichi": ["com.github.ztefn.haguichi"],
     "handbrake": ["fr.handbrake.ghb"],
     "homebank": ["fr.free.Homebank"],
-    "inkscape": ["org.inkscape.Inkscape"],
     "jdownloader": ["org.jdownloader.JDownloader"],
     "joplin": ["net.cozic.joplin_desktop"],
     "juk": ["org.kde.juk"],
@@ -127,7 +127,6 @@ aliases = {
     "scribus": ["net.scribus.Scribus"],
     "skanlite": ["org.kde.skanlite"],
     "skrooge": ["org.kde.skrooge"],
-    "smartgit": ["com.syntevo.SmartGit"],
     "smplayer": ["info.smplayer.SMPlayer"],
     "steam": ["com.valvesoftware.Steam"],
     "sublime-merge": ["com.sublimemerge.App"],
